# seaturtle_menu

seaturtle_menu is a package to help you make a terminal user input menu quickly.

## Features
- Built-in bullets:
    - Lowercase Alphabet
    - Uppercase Alphabet
    - Digits
- Ability to add custom brackets after bullets.
- Adding custom greeting messages that are printed before the menu options.

## License
seaturtle_menu uses the [MIT License](LICENSE)